==> dogtag-pki_10.8.3.orig.tar.xz: pki-10.8.3/base/ca/src/com/netscape/cms/servlet/csadmin/CAUpdateNumberRange.java <==
// --- BEGIN COPYRIGHT BLOCK ---
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// (C) 2020 Red Hat, Inc.
// All rights reserved.
// --- END COPYRIGHT BLOCK ---
package com.netscape.cms.servlet.csadmin;

import org.dogtagpki.server.ca.CAEngine;
import org.dogtagpki.server.ca.ICertificateAuthority;

import com.netscape.certsrv.base.EBaseException;
import com.netscape.certsrv.dbs.repository.IRepository;
import com.netscape.cmscore.apps.CMS;

public class CAUpdateNumberRange extends UpdateNumberRange {

    public IRepository getRepository(String type) throws EBaseException {

        CAEngine engine = (CAEngine) CMS.getCMSEngine();
        ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);

        if (type.equals("request")) {
            return ca.getRequestQueue().getRequestRepository();

        } else if (type.equals("serialNo")) {
            return ca.getCertificateRepository();

        } else if (type.equals("replicaId")) {
            return ca.getReplicaRepository();
        }

        throw new EBaseException("Unsupported repository: " + type);
    }
}

==> dogtag-pki_10.10.2.orig.tar.xz: pki-10.10.2/base/ca/src/com/netscape/cms/servlet/csadmin/CAUpdateNumberRange.java <==
// --- BEGIN COPYRIGHT BLOCK ---
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// (C) 2020 Red Hat, Inc.
// All rights reserved.
// --- END COPYRIGHT BLOCK ---
package com.netscape.cms.servlet.csadmin;

import org.dogtagpki.server.ca.CAEngine;

import com.netscape.ca.CertificateAuthority;
import com.netscape.certsrv.base.EBaseException;
import com.netscape.certsrv.dbs.repository.IRepository;

public class CAUpdateNumberRange extends UpdateNumberRange {

    public IRepository getRepository(String type) throws EBaseException {

        CAEngine engine = CAEngine.getInstance();
        CertificateAuthority ca = engine.getCA();

        if (type.equals("request")) {
            return ca.getRequestQueue().getRequestRepository();

        } else if (type.equals("serialNo")) {
            return engine.getCertificateRepository();

        } else if (type.equals("replicaId")) {
            return ca.getReplicaRepository();
        }

        throw new EBaseException("Unsupported repository: " + type);
    }
}
